@@ -25,6 +25,7 @@
 GtkStatusIcon *init_notification(void);
 void cleanup_notification(void);
 
+gboolean notification_supports_actions(void);
 void show_notification(const gchar *summary, const gchar *message,
 			const gchar *action, gint timeout, GCallback handler);
 void close_notification(void);
@@ -32,7 +33,3 @@ void close_notification(void);
 void show_icon(void);
 void hide_icon(void);
 void set_icon(gboolean enabled);
-
-void enable_blinking(void);
-void disable_blinking(void);
-gboolean query_blinking(void);
