@@ -27,6 +27,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <stdlib.h>
 
 #include "bluetooth-chooser.h"
 #include "bluetooth-chooser-button.h"
@@ -78,6 +79,14 @@ static void select_device_changed(BluetoothChooser *sel,
 	g_free (name);
 }
 
+static void selected_device_activated(BluetoothChooser *sel,
+				      gchar *address, gpointer user_data)
+{
+	GtkDialog *dialog = user_data;
+
+	gtk_dialog_response(dialog, GTK_RESPONSE_ACCEPT);
+}
+
 static void device_selected_cb(GObject *object,
 			       GParamSpec *spec, gpointer user_data)
 {
@@ -185,6 +194,11 @@ response_cb (GtkDialog *dialog, gint response_id, BluetoothChooser *selector)
 	} else {
 		g_message ("No selected device");
 	}
+
+	if (response_id == GTK_RESPONSE_DELETE_EVENT)
+		exit (0);
+
+	gtk_main_quit ();
 }
 
 static GtkWidget *
@@ -212,7 +226,10 @@ create_wizard_dialogue (void)
 			 G_CALLBACK(device_type_filter_selected_cb), dialog);
 	g_signal_connect(selector, "notify::device-category-filter",
 			 G_CALLBACK(device_category_filter_selected_cb), dialog);
-	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(dialog))), selector);
+	g_signal_connect(selector, "selected-device-activated",
+			 G_CALLBACK(selected_device_activated), dialog);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG(dialog))), selector,
+			    TRUE, TRUE, 0);
 	bluetooth_chooser_start_discovery (BLUETOOTH_CHOOSER (selector));
 
 	g_signal_connect (G_OBJECT (dialog), "response",
@@ -248,7 +265,10 @@ create_props_dialogue (void)
 			 G_CALLBACK(device_type_filter_selected_cb), dialog);
 	g_signal_connect(selector, "notify::device-category-filter",
 			 G_CALLBACK(device_category_filter_selected_cb), dialog);
-	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(dialog))), selector);
+	g_signal_connect(selector, "selected-device-activated",
+			 G_CALLBACK(selected_device_activated), dialog);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG(dialog))), selector,
+			    TRUE, TRUE, 0);
 
 	g_signal_connect (G_OBJECT (dialog), "response",
 			  G_CALLBACK (response_cb), selector);
@@ -323,7 +343,7 @@ create_filter_dialogue (void)
 		     "show-searching", TRUE,
 		     "device-category-filter", BLUETOOTH_CATEGORY_NOT_PAIRED_OR_TRUSTED,
 		     NULL);
-	gtk_box_pack_start (GTK_BOX (hbox), selector, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), selector, TRUE, TRUE, 6);
 
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (vbox);
@@ -388,7 +408,7 @@ int main(int argc, char **argv)
 
 	gtk_widget_show(dialog);
 
-	gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_main ();
 
 	gtk_widget_destroy(dialog);
 
